@@ -25,6 +25,7 @@
 #include "garminFilebasedDevice.h"
 
 #include "edge305Device.h"
+#include "gpsFunctions.h"
 
 #include <algorithm>
 #include <string>
@@ -104,32 +105,52 @@ void DeviceManager::startFindDevices() {
     struct mntent *ent = NULL;
     mounts = setmntent("/etc/mtab", "r");
 
-    Log::dbg("Searching for Edge705/Oregon300/...");
-    while ( (ent = getmntent(mounts)) != NULL ) {
-        string filesystype = ent->mnt_type;
-        if (filesystype.compare("vfat") == 0) {
-            string mountPath = ent->mnt_dir;
-
-            GpsDevice *dev = createGarminDeviceFromPath(mountPath, NULL);
-            if (dev != NULL) {
-                gpsDeviceList.push_back(dev);
-            }
-        }
-    }
-
     bool searchGarmin = true;
+    string backupPath = "";
     if (this->configuration != NULL) {
         TiXmlElement * pRoot = this->configuration->FirstChildElement( "GarminPlugin" );
         TiXmlElement * settings = NULL;
         TiXmlElement * ftools = NULL;
+        TiXmlElement * backup = NULL;
 
         if (pRoot != NULL) { settings = pRoot->FirstChildElement("Settings"); }
-        if (settings != NULL) { ftools = settings->FirstChildElement("ForerunnerTools"); } else { Log::dbg("settings is null!"); }
+        if (settings != NULL) {
+        	ftools = settings->FirstChildElement("ForerunnerTools");
+        	backup = settings->FirstChildElement("BackupWorkouts");
+        } else {
+        	Log::dbg("settings is null!");
+        }
         if (ftools != NULL) {
             searchGarmin = getXmlBoolAttribute(ftools, "enabled", true);
         } else {
 			Log::dbg("Xml Element ForerunnerTools is null!");
 		}
+        if (backup != NULL) {
+            bool doBackup = getXmlBoolAttribute(backup, "enabled", false);
+            if (doBackup) {
+            	backupPath = backup->Attribute("path");
+            } else {
+            	backupPath = "";
+            }
+        } else {
+			Log::dbg("Xml Element BackupWorkouts is null!");
+		}
+    }
+
+    Log::dbg("Searching for Edge705/Oregon300/...");
+    while ( (ent = getmntent(mounts)) != NULL ) {
+        string filesystype = ent->mnt_type;
+        string mountPath = ent->mnt_dir;
+        if (filesystype.compare("vfat") == 0) {
+            Log::dbg("Searching on ["+mountPath+"] ["+filesystype+"]");
+            GpsDevice *dev = createGarminDeviceFromPath(mountPath, NULL);
+            if (dev != NULL) {
+            	dev->setBackupPath(backupPath);
+                gpsDeviceList.push_back(dev);
+            }
+        } else {
+            Log::dbg("Not searching on ["+mountPath+"] ["+filesystype+"] - wrong fstype.");
+        }
     }
 
     string deviceName;
@@ -139,6 +160,7 @@ void DeviceManager::startFindDevices() {
         if (deviceName.length() > 0) {  // Found a device
             Log::dbg("Found device via garmintools: "+deviceName);
             Edge305Device * device = new Edge305Device(deviceName);
+            device->setBackupPath(backupPath);
             gpsDeviceList.push_back(device);
         }
     } else {
@@ -190,6 +212,7 @@ void DeviceManager::startFindDevices() {
 
                 if ((deviceEnabled) && (name!=NULL)) {
                     if (name->GetText() != NULL) {
+                        string devName = name->GetText();
                         for(unsigned int i=0; i < gpsDeviceList.size(); i++)
                         {
                             // Device exists, and is configured in configuration
@@ -198,10 +221,10 @@ void DeviceManager::startFindDevices() {
                             }
                         }
                         if (currentDevice == NULL) { // no device found
+                            Log::dbg("Creating device "+devName+" from configuration.");
 
                             currentDevice = createGarminDeviceFromPath(storagePath, NULL);
                             if (currentDevice == NULL) {
-                                string devName = name->GetText();
                                 if (Log::enabledDbg()) { Log::dbg("Device from configuration - no XML found for "+devName); }
 
                                 //TODO: Create a pseudo configuration file for this device
@@ -217,11 +240,16 @@ void DeviceManager::startFindDevices() {
                                 }
                                 currentDevice = createGarminDeviceFromPath(storagePath, doc);
                                 delete(doc);
+                            } else {
+                                Log::dbg("Created device "+devName+" from existing GarminDevice.xml configuration.");
                             }
 
                             if (currentDevice != NULL) {
+                            	currentDevice->setBackupPath(backupPath);
                                 gpsDeviceList.push_back(currentDevice);
                             }
+                        } else {
+                            Log::dbg("Ignoring device "+devName+" from configuration - existing device with same name exists.");
                         }
                     }
                 }
@@ -300,9 +328,10 @@ GpsDevice * DeviceManager::createGarminDeviceFromPath(string devicepath, TiXmlDo
         }
 
         bool garminDirFound = false;
+        string dirname = "";
         while ((dirp = readdir(dp)) != NULL) {
-            string dir = string(dirp->d_name);
-            if (dir.compare("Garmin") == 0) {
+            dirname = string(dirp->d_name);
+            if (GpsFunctions::iequals(dirname, "Garmin")) {
                 garminDirFound = true;
                 break;
             }
@@ -310,7 +339,21 @@ GpsDevice * DeviceManager::createGarminDeviceFromPath(string devicepath, TiXmlDo
         closedir(dp);
 
         if (garminDirFound) {
-            string fullPath = devicepath + "/Garmin/GarminDevice.xml";
+            string basePath = devicepath + "/" + dirname;
+            string fullPath = basePath +"/GarminDevice.xml";
+
+            // Ignore case search for file GarminDevice.xml
+            if((dp = opendir(basePath.c_str())) != NULL) {
+            	while ((dirp = readdir(dp)) != NULL) {
+					string entry = string(dirp->d_name);
+					if (GpsFunctions::iequals(entry, "GarminDevice.xml")) {
+						fullPath = basePath + "/" + entry;
+						break;
+					}
+				}
+                closedir(dp);
+            }
+
             doc = new TiXmlDocument(fullPath);
             deleteXmlDoc = true;
             if (!doc->LoadFile()) {
